==> improvements-2.0.3.tar.gz: improvements/src/Element/RangeSlider.php <==
<?php

namespace Drupal\improvements\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\FormElement;

/**
 * @FormElement("range_slider")
 */
class RangeSlider extends FormElement {

  /**
   * {@inheritDoc}
   */
  public function getInfo(): array {
    $class = get_class($this);

    return [
      '#input' => TRUE,
      '#process' => [
        [$class, 'processElement'],
      ],
      '#theme_wrappers' => ['form_element'],
      '#step' => NULL,
      '#min' => NULL,
      '#max' => NULL,
    ];
  }

  /**
   * Element process callback.
   */
  public static function processElement(array &$element, FormStateInterface $form_state, array &$complete_form): array {
    $element['#tree'] = TRUE;

    $step = $element['#step'] ?? NULL;

    if ($step > 1) {
      if (isset($element['#min'])) {
        $element['#min'] = floor($element['#min'] / $step) * $step;
      }
      if (isset($element['#max'])) {
        $element['#max'] = ceil($element['#max'] / $step) * $step;
      }
    }

    $element['from'] = [
      '#type' => 'number',
      '#title' => t('From', [], ['context' => 'number']),
      '#default_value' => $element['#default_value']['from'] ?? '',
      '#min' => $element['#min'] ?? NULL,
      '#max' => $element['#max'] ?? NULL,
      '#step' => $step,
      '#wrapper_attributes' => [
        'class' => ['form-range-slider__from-item'],
      ],
      '#attributes' => [
        'class' => ['form-range-slider__from'],
      ],
    ];

    $element['to'] = [
      '#type' => 'number',
      '#title' => t('To', [], ['context' => 'number']),
      '#default_value' => $element['#default_value']['to'] ?? '',
      '#min' => $element['#min'] ?? NULL,
      '#max' => $element['#max'] ?? NULL,
      '#step' => $step,
      '#wrapper_attributes' => [
        'class' => ['form-range-slider__to-item'],
      ],
      '#attributes' => [
        'class' => ['form-range-slider__to'],
      ],
    ];

    $element['slider'] = [
      '#markup' => '<div class="form-range-slider__slider"></div>',
    ];

    $element['#wrapper_attributes']['class'] = 'form-range-slider';

    $element['#attached']['library'][] = 'improvements/range-slider';

    return $element;
  }

}

==> improvements-2.1.0.tar.gz: improvements/src/Element/RangeSlider.php <==
<?php

namespace Drupal\improvements\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\FormElement;

/**
 * @FormElement("range_slider")
 */
class RangeSlider extends FormElement {

  /**
   * {@inheritDoc}
   */
  public function getInfo(): array {
    $class = get_class($this);

    return [
      '#input' => TRUE,
      '#process' => [
        [$class, 'processElement'],
      ],
      '#theme_wrappers' => ['form_element'],
      '#min' => NULL,
      '#max' => NULL,
      '#step' => NULL,
      '#validate_numbers' => TRUE,
    ];
  }

  /**
   * Element process callback.
   */
  public static function processElement(array &$element, FormStateInterface $form_state, array &$complete_form): array {
    $element['#tree'] = TRUE;

    $step = $element['#step'] ?? NULL;

    if ($step > 1) {
      if (isset($element['#min'])) {
        $element['#min'] = floor($element['#min'] / $step) * $step;
      }
      if (isset($element['#max'])) {
        $element['#max'] = ceil($element['#max'] / $step) * $step;
      }
    }

    $element['min'] = [
      '#type' => 'number',
      '#title' => t('From', [], ['context' => 'number']),
      '#default_value' => $element['#default_value']['min'] ?? '',
      '#min' => $element['#min'] ?? NULL,
      '#max' => $element['#max'] ?? NULL,
      '#step' => $step,
      '#wrapper_attributes' => [
        'class' => ['form-range-slider__min-item'],
      ],
      '#attributes' => [
        'class' => ['form-range-slider__min'],
      ],
    ];

    $element['max'] = [
      '#type' => 'number',
      '#title' => t('To', [], ['context' => 'number']),
      '#default_value' => $element['#default_value']['max'] ?? '',
      '#min' => $element['#min'] ?? NULL,
      '#max' => $element['#max'] ?? NULL,
      '#step' => $step,
      '#wrapper_attributes' => [
        'class' => ['form-range-slider__max-item'],
      ],
      '#attributes' => [
        'class' => ['form-range-slider__max'],
      ],
    ];

    if (!$element['#validate_numbers']) {
      $element['min']['#element_validate'] = [];
      $element['max']['#element_validate'] = [];
    }

    $element['slider'] = [
      '#markup' => '<div class="form-range-slider__slider"></div>',
    ];

    $element['#wrapper_attributes']['class'] = 'form-range-slider';

    $element['#attached']['library'][] = 'improvements/range-slider';

    return $element;
  }

}
